@@ -49,7 +49,6 @@ local default_options = {
   ['default_unknown'] = false,
   ['default_dkim_domainonly'] = true,
   ['default_emails_domainonly'] = false,
-  ['default_exclude_private_ips'] = true,
   ['default_exclude_users'] = false,
   ['default_exclude_local'] = true,
   ['default_no_ip'] = false,
@@ -91,7 +90,6 @@ local rule_schema_tbl = {
   emails_domainonly = ts.boolean:is_optional(),
   enabled = ts.boolean:is_optional(),
   exclude_local = ts.boolean:is_optional(),
-  exclude_private_ips = ts.boolean:is_optional(),
   exclude_users = ts.boolean:is_optional(),
   from = ts.boolean:is_optional(),
   hash = ts.one_of { "sha1", "sha256", "sha384", "sha512", "md5", "blake2" }:is_optional(),
